@@ -38,13 +38,18 @@ to get the next free checker id.
 
 The raw_metrics checker has no number associated since it doesn't emit any
 messages nor reports. XXX not true, emit a 07 report !
-
 """
 
-import sys
-from typing import List, Optional, Tuple, Union
+from __future__ import annotations
 
-from pylint.checkers.base_checker import BaseChecker, BaseTokenChecker
+import sys
+from typing import TYPE_CHECKING
+
+from pylint.checkers.base_checker import (
+    BaseChecker,
+    BaseRawFileChecker,
+    BaseTokenChecker,
+)
 from pylint.checkers.deprecated import DeprecatedMixin
 from pylint.checkers.mapreduce_checker import MapReduceMixin
 from pylint.utils import LinterStats, diff_string, register_plugins
@@ -54,20 +59,23 @@ if sys.version_info >= (3, 8):
 else:
     from typing_extensions import Literal
 
+if TYPE_CHECKING:
+    from pylint.lint import PyLinter
+
 
 def table_lines_from_stats(
     stats: LinterStats,
-    old_stats: Optional[LinterStats],
+    old_stats: LinterStats | None,
     stat_type: Literal["duplicated_lines", "message_types"],
-) -> List[str]:
+) -> list[str]:
     """Get values listed in <columns> from <stats> and <old_stats>,
     and return a formatted list of values.
 
     The return value is designed to be given to a ureport.Table object
     """
-    lines: List[str] = []
+    lines: list[str] = []
     if stat_type == "duplicated_lines":
-        new: List[Tuple[str, Union[str, int, float]]] = [
+        new: list[tuple[str, int | float]] = [
             ("nb_duplicated_lines", stats.duplicated_lines["nb_duplicated_lines"]),
             (
                 "percent_duplicated_lines",
@@ -75,7 +83,7 @@ def table_lines_from_stats(
             ),
         ]
         if old_stats:
-            old: List[Tuple[str, Union[str, int, float]]] = [
+            old: list[tuple[str, str | int | float]] = [
                 (
                     "nb_duplicated_lines",
                     old_stats.duplicated_lines["nb_duplicated_lines"],
@@ -119,11 +127,11 @@ def table_lines_from_stats(
         )
         new_str = f"{new_value:.3f}" if isinstance(new_value, float) else str(new_value)
         old_str = f"{old_value:.3f}" if isinstance(old_value, float) else str(old_value)
-        lines.extend((value[0].replace("_", " "), new_str, old_str, diff_str))
+        lines.extend((value[0].replace("_", " "), new_str, old_str, diff_str))  # type: ignore[arg-type]
     return lines
 
 
-def initialize(linter):
+def initialize(linter: PyLinter) -> None:
     """Initialize linter with checkers in this package."""
     register_plugins(linter, __path__[0])
 
@@ -131,6 +139,7 @@ def initialize(linter):
 __all__ = [
     "BaseChecker",
     "BaseTokenChecker",
+    "BaseRawFileChecker",
     "initialize",
     "MapReduceMixin",
     "DeprecatedMixin",
