@@ -4,13 +4,15 @@
 
 """Checker for anything related to the async protocol (PEP 492)."""
 
+from __future__ import annotations
+
 import sys
 from typing import TYPE_CHECKING
 
 import astroid
-from astroid import nodes
+from astroid import nodes, util
 
-from pylint import checkers, interfaces, utils
+from pylint import checkers
 from pylint.checkers import utils as checker_utils
 from pylint.checkers.utils import decorated_with
 
@@ -19,7 +21,6 @@ if TYPE_CHECKING:
 
 
 class AsyncChecker(checkers.BaseChecker):
-    __implements__ = interfaces.IAstroidChecker
     name = "async"
     msgs = {
         "E1700": (
@@ -38,14 +39,11 @@ class AsyncChecker(checkers.BaseChecker):
         ),
     }
 
-    def open(self):
-        self._ignore_mixin_members = utils.get_global_option(
-            self, "ignore-mixin-members"
-        )
-        self._mixin_class_rgx = utils.get_global_option(self, "mixin-class-rgx")
+    def open(self) -> None:
+        self._mixin_class_rgx = self.linter.config.mixin_class_rgx
         self._async_generators = ["contextlib.asynccontextmanager"]
 
-    @checker_utils.check_messages("yield-inside-async-function")
+    @checker_utils.only_required_for_messages("yield-inside-async-function")
     def visit_asyncfunctiondef(self, node: nodes.AsyncFunctionDef) -> None:
         for child in node.nodes_of_class(nodes.Yield):
             if child.scope() is node and (
@@ -53,11 +51,11 @@ class AsyncChecker(checkers.BaseChecker):
             ):
                 self.add_message("yield-inside-async-function", node=child)
 
-    @checker_utils.check_messages("not-async-context-manager")
+    @checker_utils.only_required_for_messages("not-async-context-manager")
     def visit_asyncwith(self, node: nodes.AsyncWith) -> None:
         for ctx_mgr, _ in node.items:
             inferred = checker_utils.safe_infer(ctx_mgr)
-            if inferred is None or inferred is astroid.Uninferable:
+            if inferred is None or isinstance(inferred, util.UninferableBase):
                 continue
 
             if isinstance(inferred, nodes.AsyncFunctionDef):
@@ -81,8 +79,10 @@ class AsyncChecker(checkers.BaseChecker):
                         if not checker_utils.has_known_bases(inferred):
                             continue
                         # Ignore mixin classes if they match the rgx option.
-                        if self._ignore_mixin_members and self._mixin_class_rgx.match(
-                            inferred.name
+                        if (
+                            "not-async-context-manager"
+                            in self.linter.config.ignored_checks_for_mixins
+                            and self._mixin_class_rgx.match(inferred.name)
                         ):
                             continue
                 else:
@@ -92,5 +92,5 @@ class AsyncChecker(checkers.BaseChecker):
             )
 
 
-def register(linter: "PyLinter") -> None:
+def register(linter: PyLinter) -> None:
     linter.register_checker(AsyncChecker(linter))
