@@ -602,10 +602,7 @@ class NameChecker(_BasicChecker):
                 # Union is a special case because it can be used as a type alias
                 # or as a type annotation. We only want to check the former.
                 assert node is not None
-                return not (
-                    isinstance(node.parent, nodes.AnnAssign)
-                    and node.parent.value is not None
-                )
+                return not isinstance(node.parent, nodes.AnnAssign)
         elif isinstance(inferred, nodes.FunctionDef):
             if inferred.qname() == "typing.TypeAlias":
                 return True
