@@ -5,10 +5,11 @@
 from __future__ import annotations
 
 import astroid
-from astroid import bases, nodes
+from astroid import bases, nodes, util
 
 from pylint import checkers
 from pylint.checkers import utils
+from pylint.interfaces import HIGH, INFERENCE
 
 
 class ImplicitBooleanessChecker(checkers.BaseChecker):
@@ -50,7 +51,6 @@ class ImplicitBooleanessChecker(checkers.BaseChecker):
     * comparison such as variable != empty_literal:
     """
 
-    # configuration section name
     name = "refactoring"
     msgs = {
         "C1802": (
@@ -64,10 +64,10 @@ class ImplicitBooleanessChecker(checkers.BaseChecker):
             {"old_names": [("C1801", "len-as-condition")]},
         ),
         "C1803": (
-            "'%s' can be simplified to '%s' as an empty sequence is falsey",
+            "'%s' can be simplified to '%s' as an empty %s is falsey",
             "use-implicit-booleaness-not-comparison",
             "Used when Pylint detects that collection literal comparison is being "
-            "used to check for emptiness; Use implicit booleaness instead"
+            "used to check for emptiness; Use implicit booleaness instead "
             "of a collection classes; empty collections are considered as false",
         ),
     }
@@ -99,7 +99,11 @@ class ImplicitBooleanessChecker(checkers.BaseChecker):
         )
         if isinstance(len_arg, generator_or_comprehension):
             # The node is a generator or comprehension as in len([x for x in ...])
-            self.add_message("use-implicit-booleaness-not-len", node=node)
+            self.add_message(
+                "use-implicit-booleaness-not-len",
+                node=node,
+                confidence=HIGH,
+            )
             return
         try:
             instance = next(len_arg.infer())
@@ -113,7 +117,11 @@ class ImplicitBooleanessChecker(checkers.BaseChecker):
         if "range" in mother_classes or (
             affected_by_pep8 and not self.instance_has_bool(instance)
         ):
-            self.add_message("use-implicit-booleaness-not-len", node=node)
+            self.add_message(
+                "use-implicit-booleaness-not-len",
+                node=node,
+                confidence=INFERENCE,
+            )
 
     @staticmethod
     def instance_has_bool(class_def: nodes.ClassDef) -> bool:
@@ -134,7 +142,9 @@ class ImplicitBooleanessChecker(checkers.BaseChecker):
             and node.op == "not"
             and utils.is_call_of_name(node.operand, "len")
         ):
-            self.add_message("use-implicit-booleaness-not-len", node=node)
+            self.add_message(
+                "use-implicit-booleaness-not-len", node=node, confidence=HIGH
+            )
 
     @utils.only_required_for_messages("use-implicit-booleaness-not-comparison")
     def visit_compare(self, node: nodes.Compare) -> None:
@@ -177,37 +187,46 @@ class ImplicitBooleanessChecker(checkers.BaseChecker):
 
                 # No need to check for operator when visiting compare node
                 if operator in {"==", "!=", ">=", ">", "<=", "<"}:
-                    collection_literal = "{}"
-                    if isinstance(literal_node, nodes.List):
-                        collection_literal = "[]"
-                    if isinstance(literal_node, nodes.Tuple):
-                        collection_literal = "()"
-
-                    instance_name = "x"
-                    if isinstance(target_node, nodes.Call) and target_node.func:
-                        instance_name = f"{target_node.func.as_string()}(...)"
-                    elif isinstance(target_node, (nodes.Attribute, nodes.Name)):
-                        instance_name = target_node.as_string()
-
-                    original_comparison = (
-                        f"{instance_name} {operator} {collection_literal}"
-                    )
-                    suggestion = (
-                        f"{instance_name}"
-                        if operator == "!="
-                        else f"not {instance_name}"
-                    )
                     self.add_message(
                         "use-implicit-booleaness-not-comparison",
-                        args=(
-                            original_comparison,
-                            suggestion,
+                        args=self._implicit_booleaness_message_args(
+                            literal_node, operator, target_node
                         ),
                         node=node,
+                        confidence=HIGH,
                     )
 
+    def _get_node_description(self, node: nodes.NodeNG) -> str:
+        return {
+            nodes.List: "list",
+            nodes.Tuple: "tuple",
+            nodes.Dict: "dict",
+            nodes.Const: "str",
+        }.get(type(node), "iterable")
+
+    def _implicit_booleaness_message_args(
+        self, literal_node: nodes.NodeNG, operator: str, target_node: nodes.NodeNG
+    ) -> tuple[str, str, str]:
+        """Helper to get the right message for "use-implicit-booleaness-not-comparison"."""
+        description = self._get_node_description(literal_node)
+        collection_literal = {
+            "list": "[]",
+            "tuple": "()",
+            "dict": "{}",
+        }.get(description, "iterable")
+        instance_name = "x"
+        if isinstance(target_node, nodes.Call) and target_node.func:
+            instance_name = f"{target_node.func.as_string()}(...)"
+        elif isinstance(target_node, (nodes.Attribute, nodes.Name)):
+            instance_name = target_node.as_string()
+        original_comparison = f"{instance_name} {operator} {collection_literal}"
+        suggestion = f"{instance_name}" if operator == "!=" else f"not {instance_name}"
+        return original_comparison, suggestion, description
+
     @staticmethod
-    def base_names_of_instance(node: bases.Uninferable | bases.Instance) -> list[str]:
+    def base_names_of_instance(
+        node: util.UninferableBase | bases.Instance,
+    ) -> list[str]:
         """Return all names inherited by a class instance or those returned by a
         function.
 
