@@ -38,11 +38,13 @@ from pylint.config.exceptions import (
 )
 from pylint.config.help_formatter import _HelpFormatter
 from pylint.config.option import Option
-from pylint.config.option_parser import OptionParser
-from pylint.config.options_provider_mixin import OptionsProviderMixIn
+from pylint.config.option_parser import OptionParser  # type: ignore[attr-defined]
+from pylint.config.options_provider_mixin import (  # type: ignore[attr-defined]
+    OptionsProviderMixIn,
+)
 from pylint.config.utils import _convert_option_to_argument, _parse_rich_type_value
 from pylint.constants import MAIN_CHECKER_NAME
-from pylint.typing import OptionDict
+from pylint.typing import DirectoryNamespaceDict, OptionDict
 
 if sys.version_info >= (3, 11):
     import tomllib
@@ -66,6 +68,14 @@ class _ArgumentsManager:
         self._config = argparse.Namespace()
         """Namespace for all options."""
 
+        self._base_config = self._config
+        """Fall back Namespace object created during initialization.
+
+        This is necessary for the per-directory configuration support. Whenever we
+        fail to match a file with a directory we fall back to the Namespace object
+        created during initialization.
+        """
+
         self._arg_parser = argparse.ArgumentParser(
             prog=prog,
             usage=usage or "%(prog)s [options]",
@@ -82,6 +92,9 @@ class _ArgumentsManager:
         self._option_dicts: dict[str, OptionDict] = {}
         """All option dictionaries that have been registered."""
 
+        self._directory_namespaces: DirectoryNamespaceDict = {}
+        """Mapping of directories and their respective namespace objects."""
+
         # TODO: 3.0: Remove deprecated attributes introduced to keep API
         # parity with optparse. Until '_maxlevel'
         with warnings.catch_warnings():
@@ -112,6 +125,7 @@ class _ArgumentsManager:
         warnings.warn(
             "options_providers has been deprecated. It will be removed in pylint 3.0.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self._options_providers
 
@@ -120,6 +134,7 @@ class _ArgumentsManager:
         warnings.warn(
             "Setting options_providers has been deprecated. It will be removed in pylint 3.0.",
             DeprecationWarning,
+            stacklevel=2,
         )
         self._options_providers = value
 
@@ -241,9 +256,12 @@ class _ArgumentsManager:
 
     def _parse_configuration_file(self, arguments: list[str]) -> None:
         """Parse the arguments found in a configuration file into the namespace."""
-        self.config, parsed_args = self._arg_parser.parse_known_args(
-            arguments, self.config
-        )
+        try:
+            self.config, parsed_args = self._arg_parser.parse_known_args(
+                arguments, self.config
+            )
+        except SystemExit:
+            sys.exit(32)
         unrecognized_options: list[str] = []
         for opt in parsed_args:
             if opt.startswith("--"):
@@ -269,6 +287,7 @@ class _ArgumentsManager:
             "reset_parsers has been deprecated. Parsers should be instantiated "
             "once during initialization and do not need to be reset.",
             DeprecationWarning,
+            stacklevel=2,
         )
         # configuration file parser
         self.cfgfile_parser = configparser.ConfigParser(
@@ -276,7 +295,7 @@ class _ArgumentsManager:
         )
         # command line parser
         self.cmdline_parser = OptionParser(Option, usage=usage)
-        self.cmdline_parser.options_manager = self  # type: ignore[attr-defined]
+        self.cmdline_parser.options_manager = self
         self._optik_option_attrs = set(self.cmdline_parser.option_class.ATTRS)
 
     def register_options_provider(
@@ -288,6 +307,7 @@ class _ArgumentsManager:
             "arguments providers should be registered by initializing ArgumentsProvider. "
             "This automatically registers the provider on the ArgumentsManager.",
             DeprecationWarning,
+            stacklevel=2,
         )
         self.options_providers.append(provider)
         non_group_spec_options = [
@@ -332,6 +352,7 @@ class _ArgumentsManager:
             "registered by initializing ArgumentsProvider. "
             "This automatically registers the group on the ArgumentsManager.",
             DeprecationWarning,
+            stacklevel=2,
         )
         # add option group to the command line parser
         if group_name in self._mygroups:
@@ -368,6 +389,7 @@ class _ArgumentsManager:
             "add_optik_option has been deprecated. Options should be automatically "
             "added by initializing an ArgumentsProvider.",
             DeprecationWarning,
+            stacklevel=2,
         )
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore", category=DeprecationWarning)
@@ -386,6 +408,7 @@ class _ArgumentsManager:
             "optik_option has been deprecated. Parsing of option dictionaries should be done "
             "automatically by initializing an ArgumentsProvider.",
             DeprecationWarning,
+            stacklevel=2,
         )
         optdict = copy.copy(optdict)
         if "action" in optdict:
@@ -423,10 +446,14 @@ class _ArgumentsManager:
         warnings.warn(
             "generate_config has been deprecated. It will be removed in pylint 3.0.",
             DeprecationWarning,
+            stacklevel=2,
         )
         options_by_section = {}
         sections = []
-        for group in self._arg_parser._action_groups:
+        for group in sorted(
+            self._arg_parser._action_groups,
+            key=lambda x: (x.title != "Main", x.title),
+        ):
             group_name = group.title
             assert group_name
             if group_name in skipsections:
@@ -438,7 +465,7 @@ class _ArgumentsManager:
                 for i in group._group_actions
                 if not isinstance(i, argparse._SubParsersAction)
             ]
-            for opt in option_actions:
+            for opt in sorted(option_actions, key=lambda x: x.option_strings[0][2:]):
                 if "--help" in opt.option_strings:
                     continue
 
@@ -482,6 +509,7 @@ class _ArgumentsManager:
             "load_provider_defaults has been deprecated. Parsing of option defaults should be done "
             "automatically by initializing an ArgumentsProvider.",
             DeprecationWarning,
+            stacklevel=2,
         )
         for provider in self.options_providers:
             with warnings.catch_warnings():
@@ -499,6 +527,7 @@ class _ArgumentsManager:
         warnings.warn(
             "read_config_file has been deprecated. It will be removed in pylint 3.0.",
             DeprecationWarning,
+            stacklevel=2,
         )
         if not config_file:
             if verbose:
@@ -570,6 +599,7 @@ class _ArgumentsManager:
         warnings.warn(
             "load_config_file has been deprecated. It will be removed in pylint 3.0.",
             DeprecationWarning,
+            stacklevel=2,
         )
         parser = self.cfgfile_parser
         for section in parser.sections():
@@ -584,6 +614,7 @@ class _ArgumentsManager:
         warnings.warn(
             "load_configuration has been deprecated. It will be removed in pylint 3.0.",
             DeprecationWarning,
+            stacklevel=2,
         )
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore", category=DeprecationWarning)
@@ -595,6 +626,7 @@ class _ArgumentsManager:
         warnings.warn(
             "DEPRECATED: load_configuration_from_config has been deprecated. It will be removed in pylint 3.0.",
             DeprecationWarning,
+            stacklevel=2,
         )
         for opt, opt_value in config.items():
             opt = opt.replace("_", "-")
@@ -611,6 +643,7 @@ class _ArgumentsManager:
         warnings.warn(
             "load_command_line_configuration has been deprecated. It will be removed in pylint 3.0.",
             DeprecationWarning,
+            stacklevel=2,
         )
         args = sys.argv[1:] if args is None else list(args)
         (options, args) = self.cmdline_parser.parse_args(args=args)
@@ -621,7 +654,7 @@ class _ArgumentsManager:
                 if value is None:
                     continue
                 setattr(config, attr, value)
-        return args
+        return args  # type: ignore[return-value]
 
     def help(self, level: int | None = None) -> str:
         """Return the usage string based on the available options."""
@@ -630,15 +663,19 @@ class _ArgumentsManager:
                 "Supplying a 'level' argument to help() has been deprecated."
                 "You can call help() without any arguments.",
                 DeprecationWarning,
+                stacklevel=2,
             )
         return self._arg_parser.format_help()
 
-    def cb_set_provider_option(self, option, opt, value, parser):  # pragma: no cover
+    def cb_set_provider_option(  # pragma: no cover
+        self, option: Any, opt: Any, value: Any, parser: Any
+    ) -> None:
         """DEPRECATED: Optik callback for option setting."""
         # TODO: 3.0: Remove deprecated method.
         warnings.warn(
             "cb_set_provider_option has been deprecated. It will be removed in pylint 3.0.",
             DeprecationWarning,
+            stacklevel=2,
         )
         if opt.startswith("--"):
             # remove -- on long option
@@ -658,16 +695,20 @@ class _ArgumentsManager:
             "global_set_option has been deprecated. You can use _arguments_manager.set_option "
             "or linter.set_option to set options on the global configuration object.",
             DeprecationWarning,
+            stacklevel=2,
         )
         self.set_option(opt, value)
 
-    def _generate_config_file(self) -> str:
+    def _generate_config_file(self, *, minimal: bool = False) -> str:
         """Write a configuration file according to the current configuration into
         stdout.
         """
         toml_doc = tomlkit.document()
+        tool_table = tomlkit.table(is_super_table=True)
+        toml_doc.add(tomlkit.key("tool"), tool_table)
+
         pylint_tool_table = tomlkit.table(is_super_table=True)
-        toml_doc.add(tomlkit.key(["tool", "pylint"]), pylint_tool_table)
+        tool_table.add(tomlkit.key("pylint"), pylint_tool_table)
 
         for group in sorted(
             self._arg_parser._action_groups,
@@ -700,19 +741,21 @@ class _ArgumentsManager:
                     continue
 
                 # Add help comment
-                help_msg = optdict.get("help", "")
-                assert isinstance(help_msg, str)
-                help_text = textwrap.wrap(help_msg, width=79)
-                for line in help_text:
-                    group_table.add(tomlkit.comment(line))
+                if not minimal:
+                    help_msg = optdict.get("help", "")
+                    assert isinstance(help_msg, str)
+                    help_text = textwrap.wrap(help_msg, width=79)
+                    for line in help_text:
+                        group_table.add(tomlkit.comment(line))
 
                 # Get current value of option
                 value = getattr(self.config, optname.replace("-", "_"))
 
                 # Create a comment if the option has no value
                 if not value:
-                    group_table.add(tomlkit.comment(f"{optname} ="))
-                    group_table.add(tomlkit.nl())
+                    if not minimal:
+                        group_table.add(tomlkit.comment(f"{optname} ="))
+                        group_table.add(tomlkit.nl())
                     continue
 
                 # Skip deprecated options
@@ -733,19 +776,24 @@ class _ArgumentsManager:
                 if optdict.get("type") == "py_version":
                     value = ".".join(str(i) for i in value)
 
+                # Check if it is default value if we are in minimal mode
+                if minimal and value == optdict.get("default"):
+                    continue
+
                 # Add to table
                 group_table.add(optname, value)
                 group_table.add(tomlkit.nl())
 
             assert group.title
-            pylint_tool_table.add(group.title.lower(), group_table)
+            if group_table:
+                pylint_tool_table.add(group.title.lower(), group_table)
 
         toml_string = tomlkit.dumps(toml_doc)
 
         # Make sure the string we produce is valid toml and can be parsed
         tomllib.loads(toml_string)
 
-        return toml_string
+        return str(toml_string)
 
     def set_option(
         self,
@@ -761,12 +809,14 @@ class _ArgumentsManager:
                 "The 'action' argument has been deprecated. You can use set_option "
                 "without the 'action' or 'optdict' arguments.",
                 DeprecationWarning,
+                stacklevel=2,
             )
         if optdict != "default_value":
             warnings.warn(
                 "The 'optdict' argument has been deprecated. You can use set_option "
                 "without the 'action' or 'optdict' arguments.",
                 DeprecationWarning,
+                stacklevel=2,
             )
 
         self.config = self._arg_parser.parse_known_args(
