@@ -2,15 +2,16 @@
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
 # Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
+from __future__ import annotations
+
 import linecache
 from typing import TYPE_CHECKING
 
 from astroid import nodes
 
 from pylint import checkers
-from pylint.checkers.utils import check_messages
-from pylint.constants import PY38_PLUS
-from pylint.interfaces import HIGH, IAstroidChecker
+from pylint.checkers.utils import only_required_for_messages
+from pylint.interfaces import HIGH
 
 if TYPE_CHECKING:
     from pylint.lint import PyLinter
@@ -19,15 +20,13 @@ if TYPE_CHECKING:
 class DocStringStyleChecker(checkers.BaseChecker):
     """Checks format of docstrings based on PEP 0257."""
 
-    __implements__ = IAstroidChecker
     name = "docstyle"
 
     msgs = {
         "C0198": (
             'Bad docstring quotes in %s, expected """, given %s',
             "bad-docstring-quotes",
-            "Used when a docstring does not have triple double quotes. "
-            "This checker only works on Python 3.8+.",
+            "Used when a docstring does not have triple double quotes.",
         ),
         "C0199": (
             "First line empty in %s docstring",
@@ -36,7 +35,7 @@ class DocStringStyleChecker(checkers.BaseChecker):
         ),
     }
 
-    @check_messages("docstring-first-line-empty", "bad-docstring-quotes")
+    @only_required_for_messages("docstring-first-line-empty", "bad-docstring-quotes")
     def visit_module(self, node: nodes.Module) -> None:
         self._check_docstring("module", node)
 
@@ -49,7 +48,9 @@ class DocStringStyleChecker(checkers.BaseChecker):
 
     visit_asyncfunctiondef = visit_functiondef
 
-    def _check_docstring(self, node_type, node):
+    def _check_docstring(
+        self, node_type: str, node: nodes.Module | nodes.ClassDef | nodes.FunctionDef
+    ) -> None:
         docstring = node.doc_node.value if node.doc_node else None
         if docstring and docstring[0] == "\n":
             self.add_message(
@@ -74,8 +75,8 @@ class DocStringStyleChecker(checkers.BaseChecker):
             elif line and line[0] == "'":
                 quotes = "'"
             else:
-                quotes = False
-            if quotes and PY38_PLUS:
+                quotes = ""
+            if quotes:
                 self.add_message(
                     "bad-docstring-quotes",
                     node=node,
@@ -84,5 +85,5 @@ class DocStringStyleChecker(checkers.BaseChecker):
                 )
 
 
-def register(linter: "PyLinter") -> None:
+def register(linter: PyLinter) -> None:
     linter.register_checker(DocStringStyleChecker(linter))
