@@ -6,16 +6,19 @@
 
 (dot generation adapted from pypy/translator/tool/make_dot.py)
 """
+
+from __future__ import annotations
+
 import codecs
 import os
 import shutil
 import subprocess
-import sys
 import tempfile
-from typing import Optional
+from collections.abc import Sequence
+from typing import Any
 
 
-def target_info_from_filename(filename):
+def target_info_from_filename(filename: str) -> tuple[str, str, str]:
     """Transforms /some/path/foo.png into ('/some/path', 'foo.png', 'png')."""
     basename = os.path.basename(filename)
     storedir = os.path.dirname(os.path.abspath(filename))
@@ -24,24 +27,24 @@ def target_info_from_filename(filename):
 
 
 class DotBackend:
-    """Dot File backend."""
+    """Dot File back-end."""
 
     def __init__(
         self,
-        graphname,
-        rankdir=None,
-        size=None,
-        ratio=None,
-        charset="utf-8",
-        renderer="dot",
-        additional_param=None,
-    ):
+        graphname: str,
+        rankdir: str | None = None,
+        size: Any = None,
+        ratio: Any = None,
+        charset: str = "utf-8",
+        renderer: str = "dot",
+        additional_param: dict[str, Any] | None = None,
+    ) -> None:
         if additional_param is None:
             additional_param = {}
         self.graphname = graphname
         self.renderer = renderer
-        self.lines = []
-        self._source = None
+        self.lines: list[str] = []
+        self._source: str | None = None
         self.emit(f"digraph {normalize_node_id(graphname)} {{")
         if rankdir:
             self.emit(f"rankdir={rankdir}")
@@ -59,7 +62,7 @@ class DotBackend:
         for param in additional_param.items():
             self.emit("=".join(param))
 
-    def get_source(self):
+    def get_source(self) -> str:
         """Returns self._source."""
         if self._source is None:
             self.emit("}\n")
@@ -70,7 +73,7 @@ class DotBackend:
     source = property(get_source)
 
     def generate(
-        self, outputfile: Optional[str] = None, mapfile: Optional[str] = None
+        self, outputfile: str | None = None, mapfile: str | None = None
     ) -> str:
         """Generates a graph file.
 
@@ -81,6 +84,7 @@ class DotBackend:
         :return: a path to the generated file
         :raises RuntimeError: if the executable for rendering was not found
         """
+        # pylint: disable=duplicate-code
         graphviz_extensions = ("dot", "gv")
         name = self.graphname
         if outputfile is None:
@@ -108,9 +112,8 @@ class DotBackend:
                     "executable not found. Install graphviz, or specify a `.gv` "
                     "outputfile to produce the DOT source code."
                 )
-            use_shell = sys.platform == "win32"
             if mapfile:
-                subprocess.call(
+                subprocess.run(
                     [
                         self.renderer,
                         "-Tcmapx",
@@ -122,21 +125,21 @@ class DotBackend:
                         "-o",
                         outputfile,
                     ],
-                    shell=use_shell,
+                    check=True,
                 )
             else:
-                subprocess.call(
+                subprocess.run(
                     [self.renderer, "-T", target, dot_sourcepath, "-o", outputfile],
-                    shell=use_shell,
+                    check=True,
                 )
             os.unlink(dot_sourcepath)
         return outputfile
 
-    def emit(self, line):
+    def emit(self, line: str) -> None:
         """Adds <line> to final output."""
         self.lines.append(line)
 
-    def emit_edge(self, name1, name2, **props):
+    def emit_edge(self, name1: str, name2: str, **props: Any) -> None:
         """Emit an edge from <name1> to <name2>.
 
         For edge properties: see https://www.graphviz.org/doc/info/attrs.html
@@ -145,7 +148,7 @@ class DotBackend:
         n_from, n_to = normalize_node_id(name1), normalize_node_id(name2)
         self.emit(f"{n_from} -> {n_to} [{', '.join(sorted(attrs))}];")
 
-    def emit_node(self, name, **props):
+    def emit_node(self, name: str, **props: Any) -> None:
         """Emit a node with given properties.
 
         For node properties: see https://www.graphviz.org/doc/info/attrs.html
@@ -154,26 +157,34 @@ class DotBackend:
         self.emit(f"{normalize_node_id(name)} [{', '.join(sorted(attrs))}];")
 
 
-def normalize_node_id(nid):
+def normalize_node_id(nid: str) -> str:
     """Returns a suitable DOT node id for `nid`."""
     return f'"{nid}"'
 
 
-def get_cycles(graph_dict, vertices=None):
-    """Return a list of detected cycles in a dictionary representing an ordered graph
-    (i.e. key are vertices and values is a list of destination vertices representing edges)
+def get_cycles(
+    graph_dict: dict[str, set[str]], vertices: list[str] | None = None
+) -> Sequence[list[str]]:
+    """Return a list of detected cycles based on an ordered graph (i.e. keys are
+    vertices and values are lists of destination vertices representing edges).
     """
     if not graph_dict:
         return ()
-    result = []
+    result: list[list[str]] = []
     if vertices is None:
-        vertices = graph_dict.keys()
+        vertices = list(graph_dict.keys())
     for vertice in vertices:
         _get_cycles(graph_dict, [], set(), result, vertice)
     return result
 
 
-def _get_cycles(graph_dict, path, visited, result, vertice):
+def _get_cycles(
+    graph_dict: dict[str, set[str]],
+    path: list[str],
+    visited: set[str],
+    result: list[list[str]],
+    vertice: str,
+) -> None:
     """Recursive function doing the real work for get_cycles."""
     if vertice in path:
         cycle = [vertice]
