@@ -16,6 +16,9 @@
 """
 import sys
 
+from pylint.config.exceptions import ArgumentPreprocessingError
+from pylint.lint.caching import load_results, save_results
+from pylint.lint.expand_modules import discover_package_path
 from pylint.lint.parallel import check_parallel
 from pylint.lint.pylinter import PyLinter
 from pylint.lint.report_functions import (
@@ -25,10 +28,10 @@ from pylint.lint.report_functions import (
 )
 from pylint.lint.run import Run
 from pylint.lint.utils import (
-    ArgumentPreprocessingError,
+    _augment_sys_path,
     _patch_sys_path,
+    augmented_sys_path,
     fix_import_path,
-    preprocess_options,
 )
 
 __all__ = [
@@ -41,7 +44,11 @@ __all__ = [
     "ArgumentPreprocessingError",
     "_patch_sys_path",
     "fix_import_path",
-    "preprocess_options",
+    "_augment_sys_path",
+    "augmented_sys_path",
+    "discover_package_path",
+    "save_results",
+    "load_results",
 ]
 
 if __name__ == "__main__":
